@@ -1,5 +1,3 @@
-import traceback
-from types import FunctionType
 from flask import Blueprint, request, Response
 
 from ..handlers.mock_handler import MockHandler
@@ -7,7 +5,6 @@ from ..handlers.proxy_handler import ProxyHandler
 from ..handlers.path_not_found_handler import RequestPathNotFound
 from ..handlers.handler_context import HandlerContext
 from ..handlers.flow_editor_handler import FlowEditorHandler
-from .. import plugin_manager
 from .. import context
 from lyrebird import log
 
@@ -47,22 +44,6 @@ def index(path=''):
 
     req_context.update_server_resp_time()
 
-    # old plugin loading function
-    # remove later
-    for plugin_name in plugin_manager.data_handler_plugins:
-        try:
-            plugin = plugin_manager.data_handler_plugins[plugin_name]
-            plugin.handle(req_context)
-            if hasattr(plugin, 'change_response'):
-                if isinstance(plugin.change_response, bool) and plugin.change_response:
-                    resp = req_context.response
-                elif isinstance(plugin.change_response, FunctionType) and plugin.change_response():
-                    resp = req_context.response
-                else:
-                    logger.error(f'Plugin {plugin_name} has attr change_response, but its not bool or function')
-        except Exception:
-            logger.error(f'plugin error {plugin_name}\n{traceback.format_exc()}')
-
     flow_editor_handler.on_response_handler(req_context)
 
     if req_context.response_source:
